# AnkiChinese

This program scrapes the ArchChinese dictionary to generate Anki flashcards.

## 1. Installation

    pip install ankichinese

## 2. Usage

    ankichinese

    -i, --input                 Input file (default: input.txt)
    -o, --output                Output file (default: output.csv)
    -d, --numDefs               Number of definitions to include (default: 5)
    -e, --numExamples           Number of examples to include (default: 3)